# Two R-packages are pre-requistes for this script to work:

# => readxl: You need to have the 
# CRAN package readxl (see https://cran.r-project.org/web/packages/readxl/index.html)
# installed
# You can do via the Package Installer from the R GUI or
# use 
# install.packages("readxl")
# from the command line.
# Of note, readxl requires PERL (https://www.perl.org/), depending on the environment, it
# may be necessary to install PERL in addition to R

# => moultonTools: moultonTools is a custom R package publicly available from
# Github (https://github.com/tbgitoo/moultonTools)
# It can be installed manually after download from the Github repository. Automated installation is also possible
# This requires first the installation of "devtools" from CRAN, for example via
# install.packages("devtools")
# With devtools installed, direct download and installation of moultonTools can be achieved via
# library(devtools) 
# install_github("tbgitoo/moultonTools")

# Having the libraries installed, they also need to be loaded
library(readxl)
library(moultonTools)

# Read the raw data from the Excel file (available at https://doi.org/10.5281/zenodo.4441090)
# If this doesn't work, make sure the working directory is set correctly so that R can find the Excel file
# also, ensure PERL and readxl work correctly
data_3d=as.data.frame(read_excel('Fig_3d.xlsx',sheet=2))

# Formatting
data_3d$Gel=as.factor(data_3d$Gel)
data_3d$Run=as.factor(data_3d$Run)
data_3d$Coating = as.factor(data_3d$Coating)

# Clustering here is along the biological replicates ("Run")
data_3d$group = paste(data_3d$Run)

# Clustering analysis on the residuals (https://www.jstor.org/stable/2683375)
per_run = aggregate(Cells_per_gel_from_Alamar_Blue_Fluorescence ~ Run + Coating,data_3d, FUN=mean)
per_coating =aggregate(Cells_per_gel_from_Alamar_Blue_Fluorescence ~  Coating,per_run, FUN=mean)
data_3d$Cells_per_gel_from_Alamar_Blue_Fluorescence_coating_effect_subtracted = data_3d$Cells_per_gel_from_Alamar_Blue_Fluorescence-per_coating$Cells_per_gel_from_Alamar_Blue_Fluorescence[match(data_3d$Coating,per_coating$Coating)]

# Moulton factor for the possible worst case (see cluster_analysis.pdf in the repository at https://doi.org/10.5281/zenodo.4441090)
moulton_factor(data_3d$Cells_per_gel_from_Alamar_Blue_Fluorescence_coating_effect_subtracted, data_3d$group)^2



