# Two R-packages are pre-requistes for this script to work:

# => readxl: You need to have the 
# CRAN package readxl (see https://cran.r-project.org/web/packages/readxl/index.html)
# installed
# You can do via the Package Installer from the R GUI or
# use 
# install.packages("readxl")
# from the command line.
# Of note, readxl requires PERL (https://www.perl.org/), depending on the environment, it
# may be necessary to install PERL in addition to R

# => moultonTools: moultonTools is a custom R package publicly available from
# Github (https://github.com/tbgitoo/moultonTools)
# It can be installed manually after download from the Github repository. Automated installation is also possible
# This requires first the installation of "devtools" from CRAN, for example via
# install.packages("devtools")
# With devtools installed, direct download and installation of moultonTools can be achieved via
# library(devtools) 
# install_github("tbgitoo/moultonTools")

# Having the libraries installed, they also need to be loaded
library(readxl)
library(moultonTools)

# Read the raw data from the Excel file (available at https://doi.org/10.5281/zenodo.4441090)
# If this doesn't work, make sure the working directory is set correctly so that R can find the Excel file
# also, ensure PERL and readxl work correctly
data_4b=as.data.frame(read_excel('Fig_4b.xlsx',sheet=2))

# Renaming: it is unhandy to have a space in the variable name
data_4b$"Experiment"=as.factor(data_4b$"Experiment #")

# In figure 4b, several markers are studied, get an intraclass-correlation value per marker
getICC_marker<-function(theData)
{

    
# Clustering along the biological replicates ("Experiment")
theData$group = paste(theData$Marker,theData$Experiment)

# Clustering analysis on the residuals (https://www.jstor.org/stable/2683375)
per_experiment = aggregate(Percentage_cells_positive ~ Experiment + Condition + Marker,theData, FUN=mean)
per_condition =aggregate(Percentage_cells_positive ~  Condition+Marker,per_experiment, FUN=mean)
theData$Percentage_cells_positive_coating_per_condition=per_condition$Percentage_cells_positive[match(paste(theData$Condition,theData$Marker),paste(per_condition$Condition,per_condition$Marker))]

theData$Percentage_cells_positive_coating_effect_subtracted = (theData$Percentage_cells_positive-theData$Percentage_cells_positive_coating_per_condition)

# Worst-case Moulton factor

return(moulton_factor(theData$Percentage_cells_positive_coating_effect_subtracted, theData$group))



}

# Apply the intraclass correlation analysis on the different markers
moulton_out = vector(mode="numeric",length=length(unique(data_4b$Marker)))
names(moulton_out)=unique(data_4b$Marker)

for(theMarker in names(moulton_out))
{
    theData=data_4b[data_4b$Marker==theMarker,]
    ret=getICC_marker(theData)
    moulton_out[theMarker]=ret
    
    
}

# We report the square for the Moulton factor at the Variance-level, not standard deviation level. 
#Also this the Moulton factor for the possible worst case (see cluster_analysis.pdf in the repository at https://doi.org/10.5281/zenodo.4441090) 
# For all the markers:
moulton_out^2

