# Two R-packages are pre-requistes for this script to work:

# => readxl: You need to have the 
# CRAN package readxl (see https://cran.r-project.org/web/packages/readxl/index.html)
# installed
# You can do via the Package Installer from the R GUI or
# use 
# install.packages("readxl")
# from the command line.
# Of note, readxl requires PERL (https://www.perl.org/), depending on the environment, it
# may be necessary to install PERL in addition to R

# => moultonTools: moultonTools is a custom R package publicly available from
# Github (https://github.com/tbgitoo/moultonTools)
# It can be installed manually after download from the Github repository. Automated installation is also possible
# This requires first the installation of "devtools" from CRAN, for example via
# install.packages("devtools")
# With devtools installed, direct download and installation of moultonTools can be achieved via
# library(devtools) 
# install_github("tbgitoo/moultonTools")

# Having the libraries installed, they also need to be loaded
library(readxl)
library(moultonTools)

# Read the raw data from the Excel file (available at https://doi.org/10.5281/zenodo.4441090)
# If this doesn't work, make sure the working directory is set correctly so that R can find the Excel file
# also, ensure PERL and readxl work correctly
data_4c=as.data.frame(read_excel('Fig_4c.xlsx',sheet=2,range="A2:I29"))


data_4c$Experiment=as.factor(data_4c$Experiment)

# Clustering analysis along the biological replicate
data_4c$group = paste(data_4c$Experiment)

# The residuals are the data required for analysis (https://www.jstor.org/stable/2683375)
per_experiment = aggregate(data_4c[,c("SOX2","Ki67","Map2")], by=list(Experiment=data_4c$Experiment,Condition=data_4c$Condition), FUN=mean)

per_condition =aggregate(per_experiment[,c("SOX2","Ki67","Map2")], by=list(Condition=per_experiment$Condition), FUN=mean)

data_4c$SOX2_per_condition=per_condition$SOX2[match(data_4c$Condition,per_condition$Condition)]

data_4c$Ki67_per_condition=per_condition$Ki67[match(data_4c$Condition,per_condition$Condition)]

data_4c$Map2_per_condition=per_condition$Map2[match(data_4c$Condition,per_condition$Condition)]

data_4c$SOX2_condition_effect_subtracted = (data_4c$SOX2-data_4c$SOX2_per_condition)
data_4c$Ki67_condition_effect_subtracted = (data_4c$Ki67-data_4c$Ki67_per_condition)
data_4c$Map2_condition_effect_subtracted = (data_4c$Map2-data_4c$Map2_per_condition)


# Moulton effect for the worst-case scenario for the different markers  (see cluster_analysis.pdf in the repository at https://doi.org/10.5281/zenodo.4441090)

cat("ICC with correction for covariate effect from condition: https://www.jstor.org/stable/2683375")
moulton_factor(data_4c$SOX2_condition_effect_subtracted, data_4c$group)^2




cat("ICC with correction for covariate effect from condition: https://www.jstor.org/stable/2683375?origin=crossref&seq=1#metadata_info_tab_contents")
moulton_factor(data_4c$Ki67_condition_effect_subtracted, data_4c$group)^2



cat("ICC with correction for covariate effect from condition: https://www.jstor.org/stable/2683375?origin=crossref&seq=1#metadata_info_tab_contents")
moulton_factor(data_4c$Map2_condition_effect_subtracted, data_4c$group)^2




