# Two R-packages are pre-requistes for this script to work:

# => readxl: You need to have the 
# CRAN package readxl (see https://cran.r-project.org/web/packages/readxl/index.html)
# installed
# You can do via the Package Installer from the R GUI or
# use 
# install.packages("readxl")
# from the command line.
# Of note, readxl requires PERL (https://www.perl.org/), depending on the environment, it
# may be necessary to install PERL in addition to R

# => moultonTools: moultonTools is a custom R package publicly available from
# Github (https://github.com/tbgitoo/moultonTools)
# It can be installed manually after download from the Github repository. Automated installation is also possible
# This requires first the installation of "devtools" from CRAN, for example via
# install.packages("devtools")
# With devtools installed, direct download and installation of moultonTools can be achieved via
# library(devtools) 
# install_github("tbgitoo/moultonTools")

# Having the libraries installed, they also need to be loaded
library(readxl)
library(moultonTools)

# Read the raw data from the Excel file (available at https://doi.org/10.5281/zenodo.4441090)
# If this doesn't work, make sure the working directory is set correctly so that R can find the Excel file
# also, ensure PERL and readxl work correctly
data_5b=as.data.frame(read_excel('Fig_5b.xlsx',sheet=2))


data_5b$Experiment=as.factor(data_5b$Experiment_number)

# Clustering analysis along the biological replicates ("Experiment")
data_5b$group = paste(data_5b$Experiment)

# Analysis on the residuals (https://www.jstor.org/stable/2683375)
data_5b$Condition=paste(data_5b$Ejected,data_5b$Gel_synthesis_diameter_mm,data_5b$Dissociation_agent)
per_experiment = aggregate(Alive_recovery_percentage ~ Experiment + Condition,data_5b, FUN=mean)
per_condition =aggregate(Alive_recovery_percentage ~  Condition,per_experiment, FUN=mean)
data_5b$Alive_recovery_percentage_coating_per_condition=per_condition$Alive_recovery_percentage[match(data_5b$Condition,per_condition$Condition)]
data_5b$Alive_recovery_percentage_coating_effect_subtracted = (data_5b$Alive_recovery_percentage-data_5b$Alive_recovery_percentage_coating_per_condition)




# Moulton factor for the possible worst case (see cluster_analysis.pdf in the repository at https://doi.org/10.5281/zenodo.4441090)
cat("ICC with correction for covariate effect from coating: https://www.jstor.org/stable/2683375")

moulton_factor(data_5b$Alive_recovery_percentage_coating_effect_subtracted, data_5b$group)


