# Two R-packages are pre-requistes for this script to work:

# => readxl: You need to have the 
# CRAN package readxl (see https://cran.r-project.org/web/packages/readxl/index.html)
# installed
# You can do via the Package Installer from the R GUI or
# use 
# install.packages("readxl")
# from the command line.
# Of note, readxl requires PERL (https://www.perl.org/), depending on the environment, it
# may be necessary to install PERL in addition to R

# => moultonTools: moultonTools is a custom R package publicly available from
# Github (https://github.com/tbgitoo/moultonTools)
# It can be installed manually after download from the Github repository. Automated installation is also possible
# This requires first the installation of "devtools" from CRAN, for example via
# install.packages("devtools")
# With devtools installed, direct download and installation of moultonTools can be achieved via
# library(devtools) 
# install_github("tbgitoo/moultonTools")

# Having the libraries installed, they also need to be loaded
library(readxl)
library(moultonTools)

# Read the raw data from the Excel file (available at https://doi.org/10.5281/zenodo.4441090)
# If this doesn't work, make sure the working directory is set correctly so that R can find the Excel file
# also, ensure PERL and readxl work correctly
data_6b=as.data.frame(read_excel('Fig_6b.xlsx',sheet=2,range="A2:O18"))

# Clustering analysis along the biological replicates ("Experiment")
data_6b$Experiment=as.factor(data_6b$Experiment)
data_6b$group = paste(data_6b$Experiment)

# Clustering analysis separately for the expression of each of these genes
genes=c("Oct4","LMX1A","FOXA2","EN1","MAP2","TH","GIRK2","PAX8","MSX1","OTX2")

# Clustering analysis on residuals (https://www.jstor.org/stable/2683375)
per_experiment = aggregate(data_6b[,genes],by=list(Experiment=data_6b$Experiment,Condition=data_6b$Condition), FUN=mean,na.rm=TRUE)
per_condition =aggregate(per_experiment[,genes],by=list(Condition=per_experiment$Condition), FUN=mean,na.rm=TRUE)

for(theGene in genes)
{
    data_6b[,paste(theGene,"_condition_removed",sep="")]=data_6b[,theGene]-per_condition[match(data_6b$Condition,per_condition$Condition),theGene]
}


# Go through the genes
moulton_factor_covariate_subtrated=vector(mode="numeric",length=length(genes))
names(moulton_factor_covariate_subtrated)=genes

for(theGene in genes)
{
        sel_OK = !is.na(data_6b[,theGene]) & !is.nan(data_6b[,theGene])
        data = data_6b[sel_OK,]
        
        n_per_experiment=aggregate(data[,theGene],by=list(Experiment=data$Experiment,Condition=data$Condition), FUN=length)
        # Keep only groups with n>1 for the clustering analysis
        data=data[(n_per_experiment$x>1)[match(paste(data$Experiment,data$Condition),paste(n_per_experiment$Experiment,n_per_experiment$Condition))],]
        
        
    
        
        moulton_factor_covariate_subtrated[theGene]=moulton_factor(data[,paste(theGene,"_condition_removed",sep="")], data$group)
        
}

# Moulton factor for the possible worst case (see cluster_analysis.pdf in the repository at https://doi.org/10.5281/zenodo.4441090)
cat("ICC with correction for covariate effect from coating: https://www.jstor.org/stable/2683375")
moulton_factor_covariate_subtrated^2


