# Two R-packages are pre-requistes for this script to work:

# => readxl: You need to have the 
# CRAN package readxl (see https://cran.r-project.org/web/packages/readxl/index.html)
# installed
# You can do via the Package Installer from the R GUI or
# use 
# install.packages("readxl")
# from the command line.
# Of note, readxl requires PERL (https://www.perl.org/), depending on the environment, it
# may be necessary to install PERL in addition to R

# => moultonTools: moultonTools is a custom R package publicly available from
# Github (https://github.com/tbgitoo/moultonTools)
# It can be installed manually after download from the Github repository. Automated installation is also possible
# This requires first the installation of "devtools" from CRAN, for example via
# install.packages("devtools")
# With devtools installed, direct download and installation of moultonTools can be achieved via
# library(devtools) 
# install_github("tbgitoo/moultonTools")

# Having the libraries installed, they also need to be loaded
library(readxl)
library(moultonTools)

# Read the raw data from the Excel file (available at https://doi.org/10.5281/zenodo.4441090)
# If this doesn't work, make sure the working directory is set correctly so that R can find the Excel file
# also, ensure PERL and readxl work correctly
data_S10_1c=as.data.frame(read_excel('Supplementary_Fig_S10.xlsx',sheet=2,range="A5:J16"))


# Formatting the data
data_S10_1c$slice=as.factor(data_S10_1c$slice)
data_S10_1c$Mouse=as.factor(data_S10_1c$Mouse)
data_S10_1c$Stem = data_S10_1c[,"Average STEM+ cells"]


# Subtraction of the main effect, which is 2D vs. Neurothread to
# be able to analyze the correlation on the error terms, not main effects (https://www.jstor.org/stable/2683375 )
per_mouse = aggregate(Stem ~ Mouse + Sample,data_S10_1c, FUN=mean)
per_Sample =aggregate(Stem ~  Sample,per_mouse, FUN=mean)
data_S10_1c$Stem_Sample_effect_subtracted = data_S10_1c$Stem-per_Sample$Stem[match(data_S10_1c$Sample,per_Sample$Sample)]


# Moulton factor, the clustering element here is the individual mouse (no overlap, 
# so use worst-case Moulton factor directly, see cluster_analysis.pdf on https://doi.org/10.5281/zenodo.4441090)
moulton_factor(data_S10_1c$Stem_Sample_effect_subtracted, data_S10_1c$Mouse)^2 # The implementation is for the standard deviations rather than the variances, and so we need to take the square
