# Two R-packages are pre-requistes for this script to work:

# => readxl: You need to have the 
# CRAN package readxl (see https://cran.r-project.org/web/packages/readxl/index.html)
# installed
# You can do via the Package Installer from the R GUI or
# use 
# install.packages("readxl")
# from the command line.
# Of note, readxl requires PERL (https://www.perl.org/), depending on the environment, it
# may be necessary to install PERL in addition to R

# => moultonTools: moultonTools is a custom R package publicly available from
# Github (https://github.com/tbgitoo/moultonTools)
# It can be installed manually after download from the Github repository. Automated installation is also possible
# This requires first the installation of "devtools" from CRAN, for example via
# install.packages("devtools")
# With devtools installed, direct download and installation of moultonTools can be achieved via
# library(devtools) 
# install_github("tbgitoo/moultonTools")

# Having the libraries installed, they also need to be loaded
library(readxl)
library(moultonTools)

# Read the raw data from the Excel file (available at https://doi.org/10.5281/zenodo.4441090)
# If this doesn't work, make sure the working directory is set correctly so that R can find the Excel file
# also, ensure PERL and readxl work correctly
data_S10_3a=as.data.frame(read_excel('Supplementary_Fig_S10.xlsx',sheet=2,range="A24:E37"))


# Data formatting
data_S10_3a$slice=as.factor(data_S10_3a$slice)
data_S10_3a$Mouse=as.factor(data_S10_3a$Mouse)
data_S10_3a$StemNF = data_S10_3a[,"NF + STEM area (um2)"]


# Subtraction of the main effect, which is 2D vs. Neurothread to
# be able to analyze the correlation on the error terms, not main effects ( https://www.jstor.org/stable/2683375 )
per_mouse = aggregate(StemNF ~ Mouse + Sample,data_S10_3a, FUN=mean)
per_Sample =aggregate(StemNF ~  Sample,per_mouse, FUN=mean)
data_S10_3a$StemNF_Sample_effect_subtracted = data_S10_3a$StemNF-per_Sample$StemNF[match(data_S10_3a$Sample,per_Sample$Sample)]


# Moulton factor, the clustering element here is the individual mouse. There is no overlap between 2D and Neurothread 
#so worst case factor is applicable (cluster_analysis.pdf on https://doi.org/10.5281/zenodo.4441090) 
moulton_factor(data_S10_3a$StemNF_Sample_effect_subtracted, data_S10_3a$Mouse)^2 # The implementation is for the standard deviations rather than the variances, and so we need to take the square

# Here, we also analyse Moulton-factor corrected t-test. This result is reported in cluster_analysis.pdf on https://doi.org/10.5281/zenodo.4441090
# The result is significant when using the technical replicates, and becomes marginally significant upon Moulton correction
# The conclusion is that due to clustering, caution needs to apply, and that a larger study would be needed. Since even with clustering correction, marginal 
# significance is achieved, it is likely that such a study would confirm the results (aka more NF-positive graft area in Neurothreads than 2D)
 
t_test_uncorrected_technical_replicates=t.test(StemNF ~ Sample, data_S10_3a)
t=t_test_uncorrected_technical_replicates$statistic
df=t_test_uncorrected_technical_replicates$parameter

p_corrected = 2*pt(t/moulton_factor(data_S10_3a$StemNF_Sample_effect_subtracted, data_S10_3a$Mouse),df)


p_corrected
