# Two R-packages are pre-requistes for this script to work:

# => readxl: You need to have the 
# CRAN package readxl (see https://cran.r-project.org/web/packages/readxl/index.html)
# installed
# You can do via the Package Installer from the R GUI or
# use 
# install.packages("readxl")
# from the command line.
# Of note, readxl requires PERL (https://www.perl.org/), depending on the environment, it
# may be necessary to install PERL in addition to R

# => moultonTools: moultonTools is a custom R package publicly available from
# Github (https://github.com/tbgitoo/moultonTools)
# It can be installed manually after download from the Github repository. Automated installation is also possible
# This requires first the installation of "devtools" from CRAN, for example via
# install.packages("devtools")
# With devtools installed, direct download and installation of moultonTools can be achieved via
# library(devtools) 
# install_github("tbgitoo/moultonTools")

# Having the libraries installed, they also need to be loaded
library(readxl)
library(moultonTools)

# Read the raw data from the Excel file (available at https://doi.org/10.5281/zenodo.4441090)
# If this doesn't work, make sure the working directory is set correctly so that R can find the Excel file
# also, ensure PERL and readxl work correctly
data_S11=as.data.frame(read_excel('Supplementary_Fig_S11.xlsx',sheet=2,range="A3:F9"))

# Formatting the data
data_S11$Slice=as.factor(data_S11$Slice)
data_S11$Mouse=as.factor(data_S11$Mouse)
data_S11$Ki67_percent = data_S11[,"percent_ki67_among_STEM"]


# Subtraction of the main effect to analyze residual error structure (see https://www.jstor.org/stable/2683375 for model and error structure
# assumptions underlying clustering analysis) 
per_mouse = aggregate(Ki67_percent ~ Mouse + Sample,data_S11, FUN=mean)
per_Sample =aggregate(Ki67_percent ~  Sample,per_mouse, FUN=mean)
data_S11$Ki67_percent_Sample_effect_subtracted = data_S11$Ki67_percent-per_Sample$Ki67_percent[match(data_S11$Sample,per_Sample$Sample)]


# Moulton factor for clustering along the mice. Although M=1, the study is small and preliminary as there were slices of only one mouse
# left for the Neurothreads, so this is in need of confirmatory studies regardless of the Moulton analysis
moulton_factor(data_S11$Ki67_percent_Sample_effect_subtracted, data_S11$Mouse)^2 # The implementation is for the standard deviations rather than the variances, and so we need to take the square
