# Two R-packages are pre-requistes for this script to work:

# => readxl: You need to have the 
# CRAN package readxl (see https://cran.r-project.org/web/packages/readxl/index.html)
# installed
# You can do via the Package Installer from the R GUI or
# use 
# install.packages("readxl")
# from the command line.
# Of note, readxl requires PERL (https://www.perl.org/), depending on the environment, it
# may be necessary to install PERL in addition to R

# => moultonTools: moultonTools is a custom R package publicly available from
# Github (https://github.com/tbgitoo/moultonTools)
# It can be installed manually after download from the Github repository. Automated installation is also possible
# This requires first the installation of "devtools" from CRAN, for example via
# install.packages("devtools")
# With devtools installed, direct download and installation of moultonTools can be achieved via
# library(devtools) 
# install_github("tbgitoo/moultonTools")

# Having the libraries installed, they also need to be loaded
library(readxl)
library(moultonTools)



# Evaluation of the fraction of beta-III positives, and within the beta-III positives, the Syn1 positve cells
# Data ranges not contiguous (columns not adjacent, rows with description inserted for clearer presentation in Excel) in the raw data, 
# so this needs to be assembled here
ranges_experiment=c("B4:B7","B11","B13","B17","B19","B22","B29:B31","B33","B35")
ranges_btub_percent=c("K4:K7","K11","K13","K17","K19","K22","K29:K31","K33","K35")
ranges_syn_among_beta_percent=c("O4:O7","O11","O13","O17","O19","O22","O29:O31","O33","O35")


# Read the raw data from the Excel file (available at https://doi.org/10.5281/zenodo.4441090)
# If this doesn't work, make sure the working directory is set correctly so that R can find the Excel file
# also, ensure PERL and readxl work correctly

# The idea is that we progressively assemble the blocks into a contiguous, R-formatted dataframe
experiment=as.data.frame(read_excel('Supplementary_Fig_S14_2_and_3.xlsx',sheet=5,range=ranges_experiment[1]))[,1]
btub_percent=as.data.frame(read_excel('Supplementary_Fig_S14_2_and_3.xlsx',sheet=5,range=ranges_btub_percent[1]))[,1]
syn_among_btub_percent=as.data.frame(read_excel('Supplementary_Fig_S14_2_and_3.xlsx',sheet=5,range=ranges_syn_among_beta_percent[1]))[,1]

for(ind in 2:length(ranges_experiment))
{
    
    new_data=as.data.frame(read_excel('Supplementary_Fig_S14_2_and_3.xlsx',sheet=5,range=ranges_experiment[ind],col_names=FALSE))
    
    

    experiment=c(experiment,new_data$...1)
    
    new_data=as.data.frame(read_excel('Supplementary_Fig_S14_2_and_3.xlsx',sheet=5,range=ranges_btub_percent[ind],col_names=FALSE))
    
    btub_percent=c(btub_percent,new_data$...1)
    
    new_data=as.data.frame(read_excel('Supplementary_Fig_S14_2_and_3.xlsx',sheet=5,range=ranges_syn_among_beta_percent[ind],col_names=FALSE))
    
    syn_among_btub_percent=c(syn_among_btub_percent,new_data$...1)

}

# Now, we can assemble the contiguous columns into a single dataframe
data_S14_2=data.frame(Experiment=experiment,Btub_percent=btub_percent, Syn_among_btub_percent=syn_among_btub_percent)

# With this analysis, we quantify the fractions of BIII positives and double positives, but there is no comparison
# For this reason there is also no need to subtract any main effect. The goal is to know whether for calculating the averages and standard deviations
# we would have to regroup per experiment or whether we can pool the technical replicates as is 

moulton_factor(data_S14_2$Btub_percent, data_S14_2$Experiment)^2 # The implementation is for the standard deviations rather than the variances, and so we need to take the square

moulton_factor(data_S14_2$Syn_among_btub_percent, data_S14_2$Experiment)^2 # The implementation is for the standard deviations rather than the variances, and so we need to take the square


