# Two R-packages are pre-requistes for this script to work:

# => readxl: You need to have the 
# CRAN package readxl (see https://cran.r-project.org/web/packages/readxl/index.html)
# installed
# You can do via the Package Installer from the R GUI or
# use 
# install.packages("readxl")
# from the command line.
# Of note, readxl requires PERL (https://www.perl.org/), depending on the environment, it
# may be necessary to install PERL in addition to R

# => moultonTools: moultonTools is a custom R package publicly available from
# Github (https://github.com/tbgitoo/moultonTools)
# It can be installed manually after download from the Github repository. Automated installation is also possible
# This requires first the installation of "devtools" from CRAN, for example via
# install.packages("devtools")
# With devtools installed, direct download and installation of moultonTools can be achieved via
# library(devtools) 
# install_github("tbgitoo/moultonTools")

# Having the libraries installed, they also need to be loaded
library(readxl)
library(moultonTools)

# Read the raw data from the Excel file (available at https://doi.org/10.5281/zenodo.4441090)
# If this doesn't work, make sure the working directory is set correctly so that R can find the Excel file
# also, ensure PERL and readxl work correctly
data_S1=as.data.frame(read_excel('Supplementary_Fig_S1.xlsx',sheet=2))


data_S1$Gel=as.factor(data_S1$Gel)

data_S1$Run=as.factor(data_S1$Run)

data_S1$Coating = as.factor(data_S1$Coating)

data_S1$group = paste(data_S1$Run)

per_run = aggregate(neurites_mm2 ~ Run + Coating,data_S1, FUN=mean)

per_coating =aggregate(neurites_mm2 ~  Coating,per_run, FUN=mean)

data_S1$neurites_mm2_coating_effect_subtracted = data_S1$neurites_mm2-per_coating$neurites_mm2[match(data_S1$Coating,per_coating$Coating)]


# Moulton factor for the possible worst case (see cluster_analysis.pdf in the repository at https://doi.org/10.5281/zenodo.4441090)
moulton_factor(data_S1$neurites_mm2_coating_effect_subtracted, data_S1$group)^2 # The implementation is for the standard deviations rather than the variances, and so we need to take the square


