# Two R-packages are pre-requistes for this script to work:

# => readxl: You need to have the 
# CRAN package readxl (see https://cran.r-project.org/web/packages/readxl/index.html)
# installed
# You can do via the Package Installer from the R GUI or
# use 
# install.packages("readxl")
# from the command line.
# Of note, readxl requires PERL (https://www.perl.org/), depending on the environment, it
# may be necessary to install PERL in addition to R

# => moultonTools: moultonTools is a custom R package publicly available from
# Github (https://github.com/tbgitoo/moultonTools)
# It can be installed manually after download from the Github repository. Automated installation is also possible
# This requires first the installation of "devtools" from CRAN, for example via
# install.packages("devtools")
# With devtools installed, direct download and installation of moultonTools can be achieved via
# library(devtools) 
# install_github("tbgitoo/moultonTools")

# Having the libraries installed, they also need to be loaded
library(readxl)
library(moultonTools)

# Read the raw data from the Excel file (available at https://doi.org/10.5281/zenodo.4441090)
# If this doesn't work, make sure the working directory is set correctly so that R can find the Excel file
# also, ensure PERL and readxl work correctly
pH6=as.data.frame(read_excel('Supplementary_Fig_S8.xlsx',sheet=2,range="B6:O18"))

# We are only interested in the aggregated values per gel, the technical images
# are irrelevant here
pH6=pH6[!is.na(pH6[,"Neurites*1000 per gel"]),c("Experiment","Gel","Neurites*1000 per gel")]

pH6$neurites_per_DAPI=pH6[,"Neurites*1000 per gel"]/1000


pH6$Gel=as.factor(pH6$Gel)

pH6$Run=as.factor(pH6$Experiment)

# Clustering analysis along the biological replicates (Column "Run")
pH6$group = paste(pH6$Run)

pH6$pH=6

# The ranges are not contiguous in the raw data file, so read them separately
pH4=as.data.frame(read_excel('Supplementary_Fig_S8.xlsx',sheet=2,range="B21:O34"))

# We are only interested in the aggregated values per gel, the technical images
# are irrelevant here
pH4=pH4[!is.na(pH4[,"Neurites*1000 per gel"]),c("Experiment","Gel","Neurites*1000 per gel")]

pH4$neurites_per_DAPI=pH4[,"Neurites*1000 per gel"]/1000


pH4$Gel=as.factor(pH4$Gel)

pH4$Run=as.factor(pH4$Experiment)

# Clustering analysis along the biological replicates (Column "Run")
pH4$group = paste(pH4$Run)

pH4$pH=4

# Now we can assemble the data needed for Fig. S8
data_S8 = rbind(pH4,pH6)


# Subtraction of the main effect (pH), to retrieve residual error structure for correlation analysis (https://www.jstor.org/stable/2683375)
per_run = aggregate(neurites_per_DAPI ~ Run + pH,data_S8, FUN=mean)

per_pH =aggregate(neurites_per_DAPI ~  pH,per_run, FUN=mean)

data_S8$neurites_per_DAPI_coating_effect_subtracted = data_S8$neurites_per_DAPI-per_pH$neurites_per_DAPI[match(data_S8$pH,per_pH$pH)]


# Moulton factor for the possible worst case (see cluster_analysis.pdf in the repository at https://doi.org/10.5281/zenodo.4441090)
moulton_factor(data_S8$neurites_per_DAPI_coating_effect_subtracted, data_S8$group)^2 # The implementation is for the standard deviations rather than the variances, and so we need to take the square


